import { useState } from "react";
import { useQuery } from "@tanstack/react-query";
import { zodiacSigns } from "@shared/schema";
import { useToast } from "@/hooks/use-toast";
import ZodiacCard from "./ZodiacCard";
import { motion } from "framer-motion";
import { useSubscription } from "@/hooks/useSubscription";
import { EnhancedHoroscopeDialog } from "./EnhancedHoroscopeDialog";
import { 
  GiRam, GiBull, GiGemini, GiCrab, GiLion, GiVirgo,
  GiLibra, GiScorpion, GiArcher, GiCapricorn, GiAquarius, GiFishEscape
} from "react-icons/gi";

// Definimos la interfaz para el horóscopo que viene de la API
interface HoroscopeData {
  id?: number;
  sign: string;
  date: string;
  content: string;
  isPremium: boolean;
}

// Iconos del zodíaco más atractivos de react-icons/gi (Game Icons)
const zodiacIcons = {
  Aries: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiRam className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Tauro: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiBull className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Géminis: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiGemini className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Cáncer: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiCrab className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Leo: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiLion className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Virgo: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiVirgo className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Libra: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiLibra className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Escorpio: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiScorpion className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Sagitario: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiArcher className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Capricornio: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiCapricorn className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Acuario: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiAquarius className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  ),
  Piscis: (
    <div className="w-12 h-12 relative flex items-center justify-center">
      <GiFishEscape className="w-full h-full text-celestial" />
      <motion.div 
        className="absolute inset-0 rounded-full bg-celestial/10"
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.3, 0.6, 0.3]
        }}
        transition={{
          duration: 2,
          repeat: Infinity,
          ease: "easeInOut"
        }}
      />
    </div>
  )
};

export default function DailyHoroscopeNew() {
  const [selectedSign, setSelectedSign] = useState<string | null>(null);
  const { toast } = useToast();
  
  const { data: horoscope, isLoading } = useQuery<HoroscopeData>({
    queryKey: [selectedSign ? `/api/horoscope/${selectedSign}` : null],
    enabled: !!selectedSign,
    staleTime: 1000 * 60 * 60, // 1 hour
  });
  
  const handleSignClick = (sign: string) => {
    console.log("Signo seleccionado:", sign);
    // Prevenir scroll usando location.hash
    if (!window.location.hash || window.location.hash !== "#horoscopo") {
      window.location.hash = "horoscopo";
    }
    setSelectedSign(sign);
  };
  
  const container = {
    hidden: { opacity: 0 },
    show: {
      opacity: 1,
      transition: {
        staggerChildren: 0.1
      }
    }
  };
  
  const item = {
    hidden: { y: 20, opacity: 0 },
    show: { y: 0, opacity: 1 }
  };

  return (
    <section id="horoscopo" className="relative py-12 xs:py-14 sm:py-16 md:py-20 lg:py-24 overflow-hidden">
      {/* Animated background with web3 elements */}
      <div className="absolute inset-0 z-0 bg-gradient-to-b from-indigo-950 via-night to-purple-950/40 bg-gradient-flow"></div>
      
      {/* Partículas flotantes eliminadas para mejorar el rendimiento */}
      
      {/* Floating geometric shapes */}
      <div className="absolute inset-0 z-0 opacity-50">
        {/* Large glowing orbs */}
        <motion.div 
          className="absolute w-[40vw] h-[40vw] rounded-full bg-gradient-to-r from-purple-900/10 to-indigo-900/5"
          style={{ top: '10%', left: '-10%' }}
          animate={{
            scale: [1, 1.1, 1],
            opacity: [0.3, 0.5, 0.3],
          }}
          transition={{
            duration: 15,
            repeat: Infinity,
            ease: "easeInOut"
          }}
        />
        <motion.div 
          className="absolute w-[35vw] h-[35vw] rounded-full bg-gradient-to-r from-indigo-900/10 to-purple-900/5"
          style={{ bottom: '5%', right: '-5%' }}
          animate={{
            scale: [1, 1.2, 1],
            opacity: [0.2, 0.4, 0.2],
          }}
          transition={{
            duration: 18,
            repeat: Infinity,
            ease: "easeInOut",
            delay: 2
          }}
        />
        
        {/* Digital constellation lines */}
        <svg className="absolute inset-0 w-full h-full opacity-30">
          {[...Array(8)].map((_, i) => (
            <motion.line
              key={i}
              x1={Math.random() * 100 + "%"}
              y1={Math.random() * 100 + "%"}
              x2={Math.random() * 100 + "%"}
              y2={Math.random() * 100 + "%"}
              stroke="rgba(147, 197, 253, 0.3)"
              strokeWidth="0.5"
              animate={{
                opacity: [0.1, 0.3, 0.1],
              }}
              transition={{
                duration: Math.random() * 5 + 8,
                repeat: Infinity,
                ease: "easeInOut",
                delay: i * 0.5
              }}
            />
          ))}
        </svg>
        
        {/* Digital network lines enhanced */}
        <svg className="absolute inset-0 w-full h-full opacity-40">
          {[...Array(4)].map((_, i) => (
            <motion.path
              key={i}
              d={`M${Math.random() * 100},${Math.random() * 100} Q${Math.random() * 100},${Math.random() * 100} ${Math.random() * 100},${Math.random() * 100}`}
              stroke="rgba(147, 197, 253, 0.4)"
              strokeWidth="0.5"
              fill="none"
              animate={{
                opacity: [0.1, 0.4, 0.1],
                pathLength: [0, 1, 0],
              }}
              transition={{
                duration: Math.random() * 8 + 10,
                repeat: Infinity,
                ease: "easeInOut",
                delay: i * 2
              }}
            />
          ))}
        </svg>
      </div>
      <div className="container mx-auto px-4 sm:px-6">
        <div className="relative z-10 mb-12 sm:mb-16 md:mb-20">
          <motion.div
            className="absolute -left-4 sm:-left-6 -top-4 sm:-top-6 w-full h-full rounded-xl opacity-70 blur-xl bg-gradient-to-r from-celestial/20 to-spiritual/20"
            animate={{
              scale: [1, 1.05, 1],
              opacity: [0.4, 0.7, 0.4],
            }}
            transition={{
              duration: 3,
              repeat: Infinity,
              ease: "easeInOut"
            }}
          />
          
          <motion.h2 
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.6 }}
            className="relative font-playfair text-3xl sm:text-4xl md:text-5xl text-center"
          >
            <div className="relative inline-block">
              <span className="bg-clip-text text-transparent bg-gradient-to-r from-purple-300 to-indigo-300">
                Tu Horóscopo
              </span>
              <motion.span 
                className="absolute -inset-1 rounded-lg opacity-50 blur-lg bg-gradient-to-r from-indigo-600/30 to-purple-600/30"
                animate={{
                  opacity: [0.3, 0.6, 0.3],
                }}
                transition={{
                  duration: 2,
                  repeat: Infinity,
                  ease: "easeInOut"
                }}
              />
            </div>{" "}
            <span className="relative">
              <span className="text-celestial neon-text">Diario</span>
              <motion.div 
                className="absolute -bottom-3 left-0 h-1 w-full bg-gradient-to-r from-celestial/0 via-celestial to-celestial/0"
                animate={{
                  width: ["0%", "100%", "0%"],
                  left: ["0%", "0%", "100%"],
                  opacity: [0, 1, 0]
                }}
                transition={{
                  duration: 3,
                  repeat: Infinity,
                  ease: "easeInOut",
                  repeatDelay: 1
                }}
              />
            </span>
          </motion.h2>
          
          <motion.div
            initial={{ opacity: 0, y: 10 }}
            whileInView={{ opacity: 1, y: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.6, delay: 0.2 }}
            className="text-center mt-4 max-w-2xl mx-auto"
          >
            <p className="text-lg text-moon/80 relative inline-block">
              <span className="relative">
                Descubre lo que las estrellas tienen preparado para ti
                <motion.span 
                  className="absolute -bottom-1 left-0 h-0.5 w-full bg-celestial/30 rounded-full"
                  animate={{
                    opacity: [0.2, 0.5, 0.2],
                    width: ["0%", "100%"],
                    left: ["0%", "0%"],
                  }}
                  transition={{
                    duration: 2,
                    repeat: Infinity,
                    repeatType: "reverse",
                    ease: "easeInOut"
                  }}
                />
              </span>
              <span className="neon-text text-celestial"> hoy</span>
            </p>
          </motion.div>
        </div>
        
        <motion.div
          variants={container}
          initial="hidden"
          whileInView="show"
          viewport={{ once: true }}
          className="grid grid-cols-2 xs:grid-cols-2 sm:grid-cols-3 lg:grid-cols-4 xl:grid-cols-6 gap-2 xs:gap-3 sm:gap-4 md:gap-5 px-1 xs:px-0"
        >
          {zodiacSigns.map((sign, index) => (
            <motion.div 
              key={sign.name} 
              variants={item}
              className="min-h-[140px] xs:min-h-[150px] sm:min-h-[170px] md:min-h-[200px]" // Altura mínima consistente
            >
              <ZodiacCard 
                sign={sign.name} 
                range={sign.range} 
                icon={zodiacIcons[sign.name as keyof typeof zodiacIcons]} 
                onClick={() => handleSignClick(sign.name)} 
              />
            </motion.div>
          ))}
        </motion.div>
      </div>
      
      {/* Usamos nuestro nuevo componente personalizado con estilo web3 */}
      {selectedSign && (
        <EnhancedHoroscopeDialog
          horoscope={horoscope || null}
          isLoading={isLoading}
          signName={selectedSign}
          onClose={() => setSelectedSign(null)}
          isOpen={!!selectedSign}
        />
      )}
    </section>
  );
}